netapp_ontap.resources.snapshot_policy API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.snapshot_policy`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

In ONTAP, scheduled Snapshot copy creation works based on Snapshot copy policies. ONTAP provides three cluster-wide Snapshot copy policies: "default", "default-1weekly" and "none". A Snapshot copy policy can have more than one schedule associated with it. A Snapshot copy policy can be linked to a storage object and based on the schedule in the policy, Snapshot copies will be created on the object at that interval. Each schedule in a Snapshot copy policy has a Snapshot copy name prefix attached to it. Every Snapshot copy created using this policy will have this prefix in its name. There is also a retention count associated with every schedule. This count indicates the maximum number of Snapshot copies that can exist for a given schedule. Once the Snapshot copy count reaches the retention count, on the next create operation, the oldest Snapshot copy is deleted.

## Snapshot copy policy APIs

The following APIs are used to perform operations related to Snapshot copy policy information:

- POST /api/storage/snapshot-policies
- GET /api/storage/snapshot-policies
- GET /api/storage/snapshot-policies/{uuid}
- PATCH /api/storage/snapshot-policies/{uuid}
- DELETE /api/storage/snapshot-policies/{uuid}

## Examples

### Creating a Snapshot copy policy

The POST operation is used to create a Snapshot copy policy with the specified attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicy()
        resource.name = "new_policy"
        resource.enabled = True
        resource.comment = "policy comment"
        resource.copies = [{"schedule": {"name": "5min"}, "count": "5", "prefix": "xyz"}]
        resource.svm.name = "vs0"
        resource.post(hydrate=True)
        print(resource)

Try it out

    SnapshotPolicy(
        {
            "svm": {"name": "vs0"},
            "copies": [{"schedule": {"name": "5min"}, "count": 5}],
            "enabled": True,
            "name": "new_policy",
            "comment": "This is a 5min schedule policy",
            "uuid": "a69d8173-450c-11e9-aa44-005056bbc848",
        }
    )

### Retrieving Snapshot copy policy attributes

The GET operation is used to retrieve Snapshot copy policy attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(SnapshotPolicy.get_collection()))

Try it out

    [
        SnapshotPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/snapshot-policies/0fa7a554-348d-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "spsv0",
                "uuid": "0fa7a554-348d-11e9-b55e-005056bbf1c8",
            }
        ),
        SnapshotPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/snapshot-policies/3c112527-2fe8-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "default",
                "uuid": "3c112527-2fe8-11e9-b55e-005056bbf1c8",
            }
        ),
        SnapshotPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/snapshot-policies/3c1c1656-2fe8-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "default-1weekly",
                "uuid": "3c1c1656-2fe8-11e9-b55e-005056bbf1c8",
            }
        ),
        SnapshotPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/snapshot-policies/3c228b82-2fe8-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "none",
                "uuid": "3c228b82-2fe8-11e9-b55e-005056bbf1c8",
            }
        ),
    ]

### Retrieving the attributes of a specific Snapshot copy policy

The GET operation is used to retrieve the attributes of a specific Snapshot copy policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicy(uuid="3c112527-2fe8-11e9-b55e-005056bbf1c8")
        resource.get()
        print(resource)

Try it out

    SnapshotPolicy(
        {
            "copies": [
                {"schedule": {"name": "hourly"}, "count": 6, "prefix": "hourly"},
                {"schedule": {"name": "daily"}, "count": 2, "prefix": "daily"},
                {"schedule": {"name": "weekly"}, "count": 2, "prefix": "weekly"},
            ],
            "enabled": True,
            "_links": {
                "self": {
                    "href": "/api/storage/snapshot-policies/3c112527-2fe8-11e9-b55e-005056bbf1c8"
                }
            },
            "name": "default",
            "scope": "cluster",
            "comment": "Default policy with hourly, daily & weekly schedules.",
            "uuid": "3c112527-2fe8-11e9-b55e-005056bbf1c8",
        }
    )

### Updating a Snapshot copy policy

The PATCH operation is used to update the specific attributes of a Snapshot copy policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicy(uuid="ae9e65c4-4506-11e9-aa44-005056bbc848")
        resource.enabled = False
        resource.patch()

### Deleting a Snapshot copy policy

The DELETE operation is used to delete a Snapshot copy policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicy(uuid="ae9e65c4-4506-11e9-aa44-005056bbc848")
        resource.delete()

## Classes

`class SnapshotPolicy (*args, **kwargs)`

  The Snapshot copy policy object is associated with a read-write volume used to create and delete Snapshot copies at regular intervals.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of Snapshot copy policies.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a Snapshot copy policy

    ### Related ONTAP commands

    - `snapshot policy delete`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of Snapshot copy policies.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of Snapshot copy policies.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a Snapshot copy policy

    ### Related ONTAP commands

    - `snapshot policy modify`
    - `snapshot policy modify-schedule`
    - `snapshot policy add-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a Snapshot copy policy

    ### Related ONTAP commands

    - `snapshot policy delete`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves details of a specific Snapshot copy policy.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a Snapshot copy policy

    ### Related ONTAP commands

    - `snapshot policy modify`
    - `snapshot policy modify-schedule`
    - `snapshot policy add-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a Snapshot copy policy.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the Snapshot copy policy.
    - `name` - Name for the Snapshot copy policy.
    - `copies.schedule` - Schedule at which Snapshot copies are captured on the volume.
    - `copies.count` - Number of Snapshot copies to maintain for this schedule.

    ### Recommended optional properties

    - `copies.prefix` - Prefix to use when creating Snapshot copies at regular intervals.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `enabled` - true * `copies.prefix` - Value of `schedule.name`

    ### Related ONTAP commands

    - `snapshot policy create`

    ### Learn more

    - `DOC /storage/snapshot-policies`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SnapshotPolicySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapshotPolicy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `comment GET POST PATCH`

    A comment associated with the Snapshot copy policy.

  `copies GET POST`

    The copies field of the snapshot_policy.

  `enabled GET POST PATCH`

    Is the Snapshot copy policy enabled?

    Example: true

  `links GET`

    The links field of the snapshot_policy.

  `name GET POST`

    Name of the Snapshot copy policy.

    Example: default

  `scope GET`

    Set to "svm" when the request is on a data SVM, otherwise set to "cluster".

    Valid choices:

    - svm
    - cluster
  `svm GET POST`

    The svm field of the snapshot_policy.

  `uuid GET`

    The uuid field of the snapshot_policy.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412